# mp-pyrho

[![image](https://img.shields.io/pypi/v/src.svg)](https://pypi.python.org/pypi/src)

[![image](https://img.shields.io/travis/jmmshn/src.svg)](https://travis-ci.com/jmmshn/src)

[![Documentation Status](https://readthedocs.org/projects/src/badge/?version=latest)](https://src.readthedocs.io/en/latest/?badge=latest)

[![Updates](https://pyup.io/repos/github/jmmshn/src/shield.svg)](https://pyup.io/repos/github/jmmshn/src/)

Python Boilerplate contains all the boilerplate you need to create a
Python package.

-   Free software: BSD license
-   Documentation: <https://src.readthedocs.io>.

## Features

-   TODO

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.
